<?php
add_action( 'wp_loaded', 'feedify_run_cmd' );
add_action( 'admin_notices', 'feedify_admin_notice' );
add_action( 'add_meta_boxes', 'feedify_meta_box_add' );
add_action( 'save_post', 'feedify_on_save_post', 1, 3 );
add_action( 'transition_post_status', 'feedify_on_transition_post_status', 10, 3 );
add_action('wp_head', 'feedify_site_script');

function feedify_site_script() {
    $feedify_domain_key = get_option('feedify_domain_key');
    if( $feedify_domain_key ) {
        ?>
        <script id="feedify_webscript">
            var feedify = feedify || {};
            window.feedify_options = {fedify_url: "https://feedify.net/"};
            var feedify_scripts = [
                'https://tpcf.feedify.net/uploads/settings/<?php echo md5($feedify_domain_key); ?>.js',
                'https://cdn.feedify.net/getjs/feedbackembad-min-2.0.js'
            ]
            for (var i = 0; i < 2; i++) {
                var s = document.createElement('script');
                s.type = 'text/javascript';
                s.src = feedify_scripts[i];
                document.getElementsByTagName('head')[0].appendChild(s);
            }
        </script>
        <?php
    }
}


function feedify_on_save_post( $post_id, $post, $updated ) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    $just_sent_notification = (get_post_meta($post_id, 'feedify_notification_already_sent', true) == true);
    if ($just_sent_notification) {
        // Reset our flag
        update_post_meta($post_id, 'feedify_notification_already_sent', false);
        return;
    }
    if (array_key_exists('send_feedify_notification', $_POST)) {
        update_post_meta($post_id, 'send_feedify_notification', true);
    } else {
        update_post_meta($post_id, 'send_feedify_notification', false);
    }
	feedify_on_transition_post_status($post->post_status, $post->post_status, $post);
}
function feedify_on_transition_post_status( $new_status, $old_status, $post ) {
    if (!(empty($post) ||
        $new_status !== "publish" ||
        $post->post_type == 'page')) {

        if( get_post_meta($post->ID, 'send_feedify_notification', true) &&
            !get_post_meta($post->ID, 'feedify_notification_already_sent', true) ) {

            $feedify_licence_key = get_option('feedify_licence_key');
            $feedify_domain_key = get_option('feedify_domain_key');
            $feedify = new FeedifyAPI($feedify_domain_key, $feedify_licence_key);

            $data = array(
                'title' => $post->post_title,
                'msg' => $post->post_excerpt,
                'url' => get_permalink($post),
                'logo_url' => get_the_post_thumbnail_url($post)
            );

            if($feedify->send_push($data)) {
                update_post_meta($post->ID, 'feedify_notification_already_sent', true);
            }
        }
    }
}
function feedify_send_push_to_server() {
    $feedify_licence_key = get_option('feedify_licence_key');
    $feedify_domain_key = get_option('feedify_domain_key');
    $feedify = new FeedifyAPI($feedify_domain_key, $feedify_licence_key);

    $data = array(
        'title'=>$_POST['push_title'],
        'msg'=>$_POST['push_message'],
        'url'=>$_POST['push_url'],
        'logo_url'=>$_POST['push_icon']
    );
    if($feedify->send_push($data)) {
        wp_redirect( admin_url( '/admin.php?page=feedify-manage-push&feedify_msg='.urlencode('Push Queued') ) );
        exit;
    } else {
        wp_redirect( admin_url( '/admin.php?page=feedify-manage-push&feedify_error='.urlencode('Error sending push') ) );
        exit;
    }

//    print_r($_POST);
//    die();
}
function feedify_meta_box_add()
{
    add_meta_box( 'feedify-meta-box-id', 'Feedify Push Notifications', 'feedify_meta_box_cb', 'post', 'side', 'high' );
}
function feedify_meta_box_cb($post) {
    $meta_box_checkbox_send_notification = true;
    if($post) {
        $meta_box_checkbox_send_notification = get_post_meta($post->ID, 'send_feedify_notification', true);
    }
    ?>
        <input type="checkbox" name="send_feedify_notification" value="true" <?php if ($meta_box_checkbox_send_notification) { echo "checked"; } ?>>
        <label>Send notification on post publish</label>
    <?php
}
function feedify_admin_notice() {
    if( isset($_GET['feedify_msg']) ) {
        ?>
        <div class="notice notice-success is-dismissible">
            <p><?php echo $_GET['feedify_msg']; ?></p>
        </div>
        <?php
    } else if( isset($_GET['feedify_error']) ) {
        ?>
        <div class="notice notice-error is-dismissible">
            <p><?php echo $_GET['feedify_error']; ?></p>
        </div>
        <?php
    }
}
function feedify_run_cmd() {
	$allowed_functions = array(
		'feedify_save_settings',
		'feedify_send_push_to_server'
	);
    if(isset($_REQUEST['feedify_cmd'])) {
        if( in_array($_REQUEST['feedify_cmd'], $allowed_functions) && is_callable($_REQUEST['feedify_cmd']) ) {
            call_user_func($_REQUEST['feedify_cmd']);
        }
    }
}