<?php
Class FeedifyAPI {

    private $api_url = 'https://feedify.net/rest/v1/';

    private $domain;
    private $api_key;

    function __construct($domain, $api_key) {
        $this->api_key = $api_key;
        $this->domain = $domain;
    }

    function getURL() {
        return $this->api_url;
    }

    function get_push($page = 1, $limit = 10) {
        try {
            $request_data = array(
                'page'=>$page,
                'limit'=>$limit
            );
            $data = $this->_call('push', 'POST', $request_data);
            return $data;
        } catch(Exception $e) {
            return false;
        }
    }

    function get_report($page = 1, $limit = 10) {
        try {
            $request_data = array(
                'page'=>$page,
                'limit'=>$limit
            );
            $data = $this->_call('reports', 'GET', $request_data);
            return $data;
        } catch(Exception $e) {
            return false;
        }
    }

    function send_push($data) {
        try {
            $data = $this->_call('push', 'POST', $data);
            return true;
        } catch(Exception $e) {
            return false;
        }
    }

    function status() {
        try {
            $data = $this->_call('status');
            return true;
        } catch(Exception $e) {
            return false;
        }
    }

    private function _call( $endpoint, $method = 'GET', $data = false ) {

        $final_url = $this->api_url.$endpoint;
        $curl = curl_init($final_url);
        $headers = array(
            "x-domain-key: {$this->domain}",
            "x-api-key: {$this->api_key}"
        );

        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);

        if($method == 'POST') {
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
        } else if($data) {
            $final_url .= '?'.http_build_query($data);
        }
        curl_setopt($curl, CURLOPT_URL, $final_url);
        $data = curl_exec($curl);
        curl_close($curl);

        $data = json_decode($data);
        if($data->status == 'error') {
            throw ( new Exception($data->data) );
        }
        return $data->data;
    }
}